<?php
/**
 * the-consult Theme Customizer Custom
 *
 * @package the-consult
 */

/**
 * Add new options the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function the_consult_custom_customize_register( $wp_customize ) {

	// the-consult sanitizer
    require get_template_directory() . '/inc/the-consult-sanitizer.php';

    // Category List.
    $the_consult_category_lists 	=	the_consult_category_lists();
    
    // Post List
    $posts_list = the_consult_post_list();
    
    //Adding the Default Setup Panel
	$wp_customize->add_panel('the_consult_default_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Default Setups','the-consult'),
	));	

	 //Add Default Sections to General Panel
	$wp_customize->get_section('title_tagline')->panel = 'the_consult_default_setups'; //priority 20
	$wp_customize->get_section('colors')->panel = 'the_consult_default_setups'; //priority 40
	$wp_customize->get_section('header_image')->panel = 'the_consult_default_setups'; //priority 60
	$wp_customize->get_section('background_image')->panel = 'the_consult_default_setups'; //priority 80
	$wp_customize->get_section('static_front_page')->panel = 'the_consult_default_setups'; //priority 120

	//General Setup
    $wp_customize->add_panel('the_consult_general_setups',array(
		'priority' => '30',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('General Setup','the-consult'),		
	));
    
    //Adding the General Setup section
	$wp_customize->add_section('the_consult_top_header',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Show Header Search ','the-consult'),
		'description' => esc_html__('Manage general setting for the site','the-consult'),
		'panel' => 'the_consult_general_setups'
	));
    
	//Enable/Disable Search
	$wp_customize->add_setting('the_consult_general_search_top_header',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_general_search_top_header',array(
        'description'   =>  esc_html__('Enable/Disable Search On Menu','the-consult'),
        'section'       =>  'the_consult_top_header',
        'setting'       =>  'the_consult_general_search_top_header',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //Bredcrumbs Setting for the-consult
    $wp_customize->add_section('the_consult_bredcrumb',array(
        'title' => esc_html__('Page Breadcrumb','the-consult'),
        'priority' => '11',
        'panel' => 'the_consult_general_setups'
    ));

    $wp_customize->add_setting(
        'the_consult_page_bg_image',
        array(
            'default' => '',
            'sanitize_callback' => 'esc_url_raw'
         )
     );
    $wp_customize->add_control(
       new WP_Customize_Image_Control(
           $wp_customize,
           'the_consult_page_bg_image',
           array(
               'label'      => esc_html__( 'Page Breadcrumb Backgeound Image', 'the-consult' ),
               'section'    => 'the_consult_bredcrumb',
               'settings'   => 'the_consult_page_bg_image',
               'priority' => 10,
           )
       )
    );  
    //starting logo alignment 
    $wp_customize->add_section('the_consult_logo_alignment', array(
       	'priority' => 50,
       	'title' => esc_html__('Logo Alignment', 'the-consult'),
       	'panel' => 'the_consult_general_setups'
	));
    
    $wp_customize->add_setting('the_consult_logo_alignment', array(
      'default' => 'left',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'the_consult_radio_sanitize_alignment_logo',
    ));
    
    $wp_customize->add_control('the_consult_logo_alignment', array(
      'type' => 'radio',
      'label' => esc_html__('Choose the layout that you want','the-consult'),
      'section' => 'the_consult_logo_alignment',
      'setting' => 'the_consult_logo_alignment',
      'choices' => array(
         'left'=>esc_html__('Left', 'the-consult'),
         'center'=>esc_html__('Center','the-consult'),
      )
    ));
    
    //starting weblyout
    $wp_customize->add_section('the_consult_weblayout', array(
       	'priority' => 50,
       	'title' => esc_html__('Web Layout', 'the-consult'),
       	'panel' => 'the_consult_general_setups'
	)); 
    $wp_customize->add_setting('the_consult_weblayout', array(
        'default' => 'fullwidth',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'the_consult_radio_sanitize_webpagelayout',
    ));

    $wp_customize->add_control('the_consult_weblayout', array(
        'type' => 'radio',
        'label' => esc_html__('Choose the layout that you want', 'the-consult'),
        'section' => 'the_consult_weblayout',
        'setting' => 'the_consult_weblayout',
        'choices' => array(
        'fullwidth' => esc_html__('Full  Layout', 'the-consult'),
        'boxed' => esc_html__('Boxed Layout', 'the-consult')
        )
    ));
    //Adding the Homepage Setup Panel
	$wp_customize->add_panel('the_consult_homepage_setups',array(
		'priority' => '30',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Homepage Setups','the-consult'),		
	));

	//Adding the Slider Setup Section
	$wp_customize->add_section('the_consult_slider_setups',array(
		'priority' => '01',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Slider Setups','the-consult'),
		'description' => esc_html__('Manage Slides for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
	));
    
	//slider section
	$wp_customize->add_setting('the_consult__slider_section_option',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult__slider_section_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_slider_setups',
        'setting'       =>  'the_consult__slider_section_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //select category for slider
   	$wp_customize->add_setting('the_consult_slider_section_category',array(
        'default'           =>  '',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control(
    'the_consult_slider_section_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_slider_setups',
        'setting'       =>  'the_consult_slider_section_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );
    

    //Starting Below Slider Section
    $wp_customize->add_section('the_consult_bslider_setups',array(
		'priority' => '9',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Below Slider Section','the-consult'),
		'description' => esc_html__('Below Slider','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    $wp_customize->add_setting('the_consult_below_slider_option',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_below_slider_option',array(
        'description'   =>  esc_html__('Do you want to enable this section?','the-consult'),
        'section'       =>  'the_consult_bslider_setups',
        'setting'       =>  'the_consult_below_slider_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //select category for feature section
   	$wp_customize->add_setting('the_consult_below_slider_category',array(
        'default'           =>  '0',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control('the_consult_below_slider_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_bslider_setups',
        'setting'       =>  'the_consult_below_slider_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );
    
    //Starting About Us Section
    $wp_customize->add_section('the_consult_about_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('About Us Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site ','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    $wp_customize->add_setting('the_consult_about_section_option',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_about_section_option',array(
        'description'   =>  esc_html__('Do you want to enable this section?','the-consult'),
        'section'       =>  'the_consult_about_setups',
        'setting'       =>  'the_consult_about_section_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //select post for about section 
    $wp_customize->add_setting('the_consult_about_post',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_about_post', array(
        'type' => 'select',
        'label' => esc_html__('About Us Post','the-consult'),
        'section' => 'the_consult_about_setups',
        'setting' => 'the_consult_about_post',
        'choices' => $posts_list
    ));
    	            
    //About Title
	$wp_customize->add_setting('about_us_title', array(
		'default' => esc_html__('About Us','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));

	$wp_customize->add_control('about_us_title',array(
		'type' => 'text',
		'label' => esc_html__('About Us Section Title','the-consult'),
		'section' => 'the_consult_about_setups',
		'setting' => 'about_us_title'
	));
    
     //About Us image
    $wp_customize->add_setting('the_consult_about_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
    ));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'the_consult_about_bkgimage', array(
		'label' => esc_html__('Image for About Us', 'the-consult'),
		'section' => 'the_consult_about_setups',
		'setting' => 'the_consult_about_bkgimage'
	   )
    )); 
    
     // Starting Feature Section
    $wp_customize->add_section('the_consult_feature_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Feature Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
	));
    
    // Enable/Disable This Section
    $wp_customize->add_setting('the_consult_feature_section_option',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_feature_section_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_feature_setups',
        'setting'       =>  'the_consult_feature_section_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //select category for feature section
   	$wp_customize->add_setting('the_consult_feature_section_category',array(
        'default'           =>  '0',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control('the_consult_feature_section_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_feature_setups',
        'setting'       =>  'the_consult_feature_section_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );

    //Feature Section title
	$wp_customize->add_setting('feature_homepage_title', array(
		'default' => esc_html__('Awesome Features','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('feature_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('Feature Section Title','the-consult'),
		'section' => 'the_consult_feature_setups',
		'setting' => 'feature_homepage_title'
	));
    
	//feature section Subtitle
    $wp_customize->add_setting('the_consult_feature_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_control('the_consult_feature_desc',array(
        'type' => 'text',
        'label' => esc_html__('Feature Section Subtitle','the-consult'),
        'section' => 'the_consult_feature_setups',
        'setting' => 'the_consult_feature_desc'
    ));


    //  Starting Couter Section
    $wp_customize->add_section('the_consult_counter_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Counter Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    //Enable/Disable This Section
    $wp_customize->add_setting('the_consult_counter_section_option',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_counter_section_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_counter_setups',
        'setting'       =>  'the_consult_counter_section_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //Counter Section title
	$wp_customize->add_setting('counter_homepage_title', array(
		'default' => esc_html__('Helping Everyone','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('counter_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('Counter Section Title','the-consult'),
		'section' => 'the_consult_counter_setups',
		'setting' => 'counter_homepage_title'
	));
    
	//Counter section description
    $wp_customize->add_setting('the_consult_counter_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    $wp_customize->add_control('the_consult_counter_desc',array(
        'type' => 'textarea',
        'label' => esc_html__('Counter Section Description','the-consult'),
        'section' => 'the_consult_counter_setups',
        'setting' => 'the_consult_counter_desc'
    ));
    
    //Starting First Counter
    $wp_customize->add_setting(
    'first_counter_icon_sec_separator',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'first_counter_icon_sec_separator', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( ' First  Counter', 'the-consult' ),
            'section' 	=> 'the_consult_counter_setups',
             'priority'  => '20'
             )	            	
            )
    );
    
    $wp_customize->add_setting(
    'first_counter_title', 
    	array(
        	'default' => 'Happy Clients',
    	    'sanitize_callback' => 'sanitize_text_field',
    	    'transport' => 'postMessage'
        )
    );    
    $wp_customize->add_control(
    'first_counter_title',
    array(
        'type' => 'text',
        'label' => esc_html__( 'Counter Title', 'the-consult' ),
        'section' => 'the_consult_counter_setups',
        'priority' => '21'
        )
    );
    
    $wp_customize->add_setting(
    	'first_counter_number', 
        array(
            'default' => '9928',
            'sanitize_callback' => 'the_consult_sanitize_number',
            'transport' => 'postMessage'
	    )
    );    
    $wp_customize->add_control(
    	'first_counter_number',
    	    array(
    		'type' => 'number',
    		'label' => esc_html__( 'counter Number', 'the-consult' ),
    		'section' => 'the_consult_counter_setups',
    		   'priority' => '22'
         )
    );

    $wp_customize->add_setting(
     'first_counter_icon',
	    array(
	    'default' => 'fa fa-users',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'first_counter_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'counter Icon', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_counter_setups',
          'priority'  => '23',
            )	            	
        )
    );
    
    //Second Counter
    $wp_customize->add_setting(
    'Second_counter_icon_sec_separator',
	array(
	    'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	      )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
    $wp_customize, 
    'Second_counter_icon_sec_separator', 
    array(
    'type' 		=> 'the_consult_separator',
        'label' 	=> esc_html__( ' Second  Counter', 'the-consult' ),
        'section' 	=> 'the_consult_counter_setups',
         'priority'  => '24'
            )	            	
        )
    );
    
    $wp_customize->add_setting(
    'second_counter_title', 
    	array(
            'default' => 'Projects Ready',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage'
         )
    );
    $wp_customize->add_control(
        'second_counter_title',
        array(
            'type' => 'text',
            'label' => esc_html__( 'Second Counter Title', 'the-consult' ),
            'section' => 'the_consult_counter_setups',
            'priority' => '25'
        )
    );
    
    $wp_customize->add_setting(
    'second_counter_number', 
        array(
            'default' => '2341',
            'sanitize_callback' => 'the_consult_sanitize_number',
            'transport' => 'postMessage'
        )
    );    
    $wp_customize->add_control(
        'second_counter_number',
        array(
            'type' => 'number',
            'label' => esc_html__( 'Second counter Number', 'the-consult' ),
            'section' => 'the_consult_counter_setups',
            'priority' => '26'
        )
    );
    
    $wp_customize->add_setting(
     'second_counter_icon',
	    array(
	    'default' => 'fa fa-briefcase',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'second_counter_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Second counter Icon', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_counter_setups',
          'priority'  => '27',
            )	            	
        )
    ); 
    
    //starting third counter
    $wp_customize->add_setting(
    'third_counter_icon_sec_separator',
	array(
	    'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	      )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 'third_counter_icon_sec_separator', 
            array(
            'type' 		=> 'the_consult_separator',
                'label' 	=> esc_html__( ' Third Counter', 'the-consult' ),
                'section' 	=> 'the_consult_counter_setups',
                 'priority'  => '28'
            )	            	
        )
    );
    
    $wp_customize->add_setting(
    'third_counter_title', 
    	array(
    	'default' => 'Working Days',
    	    'sanitize_callback' => 'sanitize_text_field',
    	    'transport' => 'postMessage'
    		       )
    );    
    $wp_customize->add_control(
    'third_counter_title',
        array(
        'type' => 'text',
        'label' => esc_html__( 'Third Counter Title', 'the-consult' ),
        'section' => 'the_consult_counter_setups',
        'priority' => '29'
        )
    );
    
    $wp_customize->add_setting(
    'third_counter_number', 
        array(
        'default' => '1234',
        'sanitize_callback' => 'the_consult_sanitize_number',
        'transport' => 'postMessage'
        )
    );
    $wp_customize->add_control(
    'third_counter_number',
        array(
            'type' => 'number',
            'label' => esc_html__( 'Third counter Number', 'the-consult' ),
            'section' => 'the_consult_counter_setups',
            'priority' => '30'
        )
    );
    
    $wp_customize->add_setting(
     'third_counter_icon',
	    array(
	    'default' => 'fa fa-calendar-check-o',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'third_counter_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Second counter Icon', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_counter_setups',
          'priority'  => '31',
            )	            	
        )
    );
    
    //Counter image
    $wp_customize->add_setting('the_consult_counter_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'the_consult_counter_bkgimage', array(
		'label' => esc_html__('Image for Counter', 'the-consult'),
		'section' => 'the_consult_counter_setups',
		'setting' => 'the_consult_counter_bkgimage'
	))); 

    //starting call to action Section
    $wp_customize->add_section('the_consult_call_to_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Call To Action Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    // Enable/Disable This Section
    $wp_customize->add_setting('the_consult_call_to_action_setups',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_call_to_action_setups',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_call_to_setups',
        'setting'       =>  'the_consult_call_to_action_setups',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );

    //select post for Call to section 
    $wp_customize->add_setting('the_consult_call_to_post',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_call_to_post', array(
        'type' => 'select',
        'label' => esc_html__('Call To Action Post','the-consult'),
        'section' => 'the_consult_call_to_setups',
        'setting' => 'the_consult_call_to_post',
        'choices' => $posts_list
    ));
    
    // Read More Text For the Call to Section
    $wp_customize->add_setting(
    'the_consult_call_to_section_readmore',array(
        'default'           =>  esc_html__('Send Request','the-consult'),
        'sanitize_callback' =>  'sanitize_text_field',
        )
    );

    $wp_customize->add_control(
        'the_consult_call_to_section_readmore',array(
            'priority'      =>  23,
            'label'         =>  esc_html__('Send Request','the-consult'),
            'section'       =>  'the_consult_call_to_setups',
            'setting'       =>  'the_consult_call_to_section_readmore',
            'type'          =>  'text',  
        )                                     
    );
    
    // Read More Button Link
    $wp_customize->add_setting(
    'the_consult_call_to_section_readmore_link',array(
        'default'           =>  '',
        'sanitize_callback' =>  'esc_url_raw',
        )
    );

    $wp_customize->add_control(
        'the_consult_call_to_section_readmore_link',array(
            'priority'      =>  24,
            'label'         =>  esc_html__('Button Link','the-consult'),
            'section'       =>  'the_consult_call_to_setups',
            'setting'       =>  'the_consult_call_to_section_readmore_link',
            'type'          =>  'text',  
        )                                     
    );
    //Call To image
    $wp_customize->add_setting('the_consult_call_to_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
    ));

	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'the_consult_call_to_bkgimage', array(
		'label' => esc_html__('Image for Call To Action Section', 'the-consult'),
		'section' => 'the_consult_call_to_setups',
		'setting' => 'the_consult_call_to_bkgimage'
	))); 

	//Starting Latest News Section
    $wp_customize->add_section('the_consult_latest_news_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Latest News Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
	));
    
    $wp_customize->add_setting('the_consult_latest_news_section',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_latest_news_section',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_latest_news_setups',
        'setting'       =>  'the_consult_latest_news_section',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //Latest News Section title
	$wp_customize->add_setting('latest_news_homepage_title', array(
		'default' => esc_html__('Latest Project','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('latest_news_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('Latest News Section Title','the-consult'),
		'section' => 'the_consult_latest_news_setups',
		'setting' => 'latest_news_homepage_title'
	));
    
	//latest section Subtitle
    $wp_customize->add_setting('the_consult_latest_news_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_control('the_consult_latest_news_desc',array(
        'type' => 'text',
        'label' => esc_html__('Latest News Section Subtitle','the-consult'),
        'section' => 'the_consult_latest_news_setups',
        'setting' => 'the_consult_latest_news_desc'
    ));
    //select category for latest News section
   	$wp_customize->add_setting('the_consult_latest_news_section_category',array(
        'default'           =>  '0',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control('the_consult_latest_news_section_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_latest_news_setups',
        'setting'       =>  'the_consult_latest_news_section_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );

    //Starting Service Section
    $wp_customize->add_section('the_consult_service_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Service Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    // Enable/Disable This Section
    $wp_customize->add_setting('the_consult_service_action_setups',
        array(
            'default'           =>  'no',
            'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_service_action_setups',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_service_setups',
        'setting'       =>  'the_consult_service_action_setups',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //Latest News Section title
	$wp_customize->add_setting('the_consul_service_homepage_title', array(
		'default' => esc_html__('Our Service','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('the_consul_service_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('Service Section Title','the-consult'),
		'section' => 'the_consult_service_setups',
		'setting' => 'the_consul_service_homepage_title',
        'priority'      =>  6,
	));
    
	//latest section Subtitle
    $wp_customize->add_setting('the_consul_service_homepage_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_control('the_consul_service_homepage_desc',array(
        'type' => 'text',
        'label' => esc_html__('Service Section Subtitle','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consul_service_homepage_desc',
        'priority'      =>  7,
    ));
    
    
    
    //Starting First Service
    $wp_customize->add_setting(
    'first_service_post_one_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'first_service_post_one_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post One', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 8
             )	            	
            )
    );
    
    $wp_customize->add_setting(
     'first_service_icon',
	    array(
	    'default' => ' fa fa-suitcase',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
        $wp_customize, 
        'first_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon One', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 10,
            )	            	
        )
    );
    
    //service first Post
    $wp_customize->add_setting('the_consult_service_post_1',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_1', array(
        'type' => 'select',
        'label' => esc_html__('Service Post One','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_1',
        'choices' => $posts_list,
        'priority'  => 12,
    ));
    
    
    //Starting Second Service
    $wp_customize->add_setting(
    'first_service_post_two_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'first_service_post_two_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Three', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 15
             )	            	
            )
    );
    
    $wp_customize->add_setting(
     'second_service_icon',
	    array(
	    'default' => 'fa-coffee',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'second_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Two', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 16,
            )	            	
        )
    );
    
    //service Second Post
    $wp_customize->add_setting('the_consult_service_post_2',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_2', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Two','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_2',
        'choices' => $posts_list,
        'priority'  => 17,
    ));
    
    $wp_customize->add_setting(
    'first_service_post_three_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'first_service_post_three_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Three', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 20
             )	            	
            )
    );
    
    $wp_customize->add_setting(
     'third_service_icon',
	    array(
	    'default' => 'fa fa-lemon-o',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'third_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Srvice Icon Three', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 21,
            )	            	
        )
    );
    
    //service Third Post
    $wp_customize->add_setting('the_consult_service_post_3',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_3', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Three','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_3',
        'choices' => $posts_list,
         'priority'  => 22,
    ));
    
    
    
    $wp_customize->add_setting(
    'first_service_post_four_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'first_service_post_four_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Four', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 25
             )	            	
            )
    );
    $wp_customize->add_setting(
     'forth_service_icon',
	    array(
	    'default' => 'fa fa-skyatlas',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'forth_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Four', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 26,
            )	            	
        )
    );
    //forth service Post
    $wp_customize->add_setting('the_consult_service_post_4',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_4', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Four','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_4',
        'choices' => $posts_list,
        'priority'  => 27,
    ));
    
    $wp_customize->add_setting(
    'service_post_five_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'service_post_five_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Five', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 28
             )	            	
            )
    );
    $wp_customize->add_setting(
     'five_service_icon',
	    array(
	    'default' => 'fa fa-skyatlas',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'five_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Five', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 29,
            )	            	
        )
    );
    //Five service Post
    $wp_customize->add_setting('the_consult_service_post_5',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_5', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Five','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_5',
        'choices' => $posts_list,
        'priority'  => 30,
    ));
    
    $wp_customize->add_setting(
    'service_post_six_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'service_post_six_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Six', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 35
             )	            	
            )
    );
    $wp_customize->add_setting(
     'six_service_icon',
	    array(
	    'default' => 'fa fa-skyatlas',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'six_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Six', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 36,
            )	            	
        )
    );
    //Six service Post
    $wp_customize->add_setting('the_consult_service_post_6',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_6', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Six','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_6',
        'choices' => $posts_list,
        'priority'  => 37,
    ));
    
    $wp_customize->add_setting(
    'service_post_seven_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'service_post_seven_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Seven', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 38
             )	            	
            )
    );
    $wp_customize->add_setting(
     'seven_service_icon',
	    array(
	    'default' => 'fa fa-skyatlas',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'seven_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Seven', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 39,
            )	            	
        )
    );
    //Seven service Post
    $wp_customize->add_setting('the_consult_service_post_7',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_7', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Seven','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_7',
        'choices' => $posts_list,
        'priority'  => 40,
    ));
    
    $wp_customize->add_setting(
    'service_post_eight_sep',array(
        'default' => '',
                'sanitize_callback' => 'sanitize_text_field',
          )
    );
    $wp_customize->add_control( new the_consult_Customize_Section_Separator(
        $wp_customize, 
        'service_post_eight_sep', 
        array(
        'type' 		=> 'the_consult_separator',
            'label' 	=> esc_html__( 'Service Post Eight', 'the-consult' ),
            'section' 	=> 'the_consult_service_setups',
             'priority'  => 41
             )	            	
            )
    );
    $wp_customize->add_setting(
     'eight_service_icon',
	    array(
	    'default' => 'fa fa-skyatlas',
	    'sanitize_callback' => 'sanitize_text_field',
	     'transport' => 'postMessage'
	     )
    );
    $wp_customize->add_control( new the_consult_Customize_Icons_Control(
    $wp_customize, 
        'eight_service_icon', 
         array(
        'type' 		=> 'the_consult_icons',	                
        'label' 	=> esc_html__( 'Service Icon Eight', 'the-consult' ),
        'description' 	=> esc_html__( 'Choose the icon from lists.', 'the-consult' ),
        'section' 	=> 'the_consult_service_setups',
          'priority'  => 42,
            )	            	
        )
    );
    //Eight service Post
    $wp_customize->add_setting('the_consult_service_post_8',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_service_post_8', array(
        'type' => 'select',
        'label' => esc_html__('Service Post Eight','the-consult'),
        'section' => 'the_consult_service_setups',
        'setting' => 'the_consult_service_post_8',
        'choices' => $posts_list,
        'priority'  => 43,
    ));
    
    //Service  image
    $wp_customize->add_setting('the_consult_service_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'the_consult_service_bkgimage', array(
		'label' => esc_html__('Image for Service', 'the-consult'),
		'section' => 'the_consult_service_setups',
		 'priority'  => 50,
		'setting' => 'the_consult_service_bkgimage'
	)));


    //Starting Contact Us Section
    $wp_customize->add_section('the_consult_Contact_us',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Contact us Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
    ));
    
    // Enable/Disable This Section
    $wp_customize->add_setting('the_consult_Contact_us_setups',
    array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_Contact_us_setups',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_Contact_us',
        'setting'       =>  'the_consult_Contact_us_setups',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    //Latest News Section title
	$wp_customize->add_setting('the_consul_contact_homepage_title', array(
		'default' => esc_html__('Contact Us','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('the_consul_contact_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('contact Section Title','the-consult'),
		'section' => 'the_consult_Contact_us',
		'setting' => 'the_consul_contact_homepage_title',
        'priority'      =>  6,
	));
    
	//latest section Subtitle
    $wp_customize->add_setting('the_consul_contact_homepage_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_control('the_consul_contact_homepage_desc',array(
        'type' => 'text',
        'label' => esc_html__('Contact Section Subtitle','the-consult'),
        'section' => 'the_consult_Contact_us',
        'setting' => 'the_consul_contact_homepage_desc',
        'priority'      =>  7,
    ));
    
    
     $wp_customize->add_setting(
    'the_consult_contact_section_contact',array(
        'default'           =>  esc_html__('Contact Us','the-consult'),
        'sanitize_callback' =>  'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
    'the_consult_contact_section_contact',array(
        'priority'      =>  10,
        'label'         =>  esc_html__('Fill your Number','the-consult'),
        'section'       =>  'the_consult_Contact_us',
        'setting'       =>  'the_consult_contact_section_contact',
        'type'          =>  'text',  
        )                                     
    );
    
    $wp_customize->add_setting(
    'the_consult_contact_us_section_mail_link',array(
        'default'           =>  esc_html__('support@themerulerss.com','the-consult'),
        'sanitize_callback' =>  'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
    'the_consult_contact_us_section_mail_link',array(
        'priority'      =>  12,
        'label'         =>  esc_html__('Fill The Contact Email','the-consult'),
        'section'       =>  'the_consult_Contact_us',
        'setting'       =>  'the_consult_contact_us_section_mail_link',
        'type'          =>  'text',  
        )                                     
    );
    
    $wp_customize->add_setting('the_consult_contact_form_post',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_contact_form_post', array(
        'type' => 'select',
        'label' => esc_html__('Contact Form Post','the-consult'),
        'description' => esc_html__('Note: Add Contact Form 7 Shortcode on Post Content','the-consult'),
        'section' => 'the_consult_Contact_us',
        'setting' => 'the_consult_contact_form_post',
        'choices' => $posts_list,
        'priority'      =>  14,
    ));
    
    $wp_customize->add_setting('the_consult_map_post',array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
   
    $wp_customize->add_control('the_consult_map_post', array(
        'type' => 'select',
        'label' => esc_html__('Contact Map Post','the-consult'),
        'description' => esc_html__('Note: Add Map Iframe on Post Content','the-consult'),
        'section' => 'the_consult_Contact_us',
        'setting' => 'the_consult_map_post',
        'choices' => $posts_list,
        'priority'      =>  16,
    ));
    
    //Starting Testimonial Section
     $wp_customize->add_section('the_consult_testimonial_setups',array(
    		'priority' => '10',
    		'capability' => 'edit_theme_options',
    		'theme_supports' => '',
    		'title' => esc_html__('Testimonial Section','the-consult'),
    		'description' => esc_html__('Manage This Section for the site','the-consult'),
    		'panel' => 'the_consult_homepage_setups'
    ));
    // Enable/Disable This Section
	 $wp_customize->add_setting('the_consult_testimonial_option',
        array(
            'default'           =>  'no',
            'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
            )
    );
    $wp_customize->add_control('the_consult_testimonial_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_testimonial_setups',
        'setting'       =>  'the_consult_testimonial_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
	
	 //category for the testimonial  section
    $wp_customize->add_setting('the_consult_testimonial_section_category',array(
        'default'           =>  '0',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control('the_consult_testimonial_section_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_testimonial_setups',
        'setting'       =>  'the_consult_testimonial_section_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );
    
    // testimonial title
    $wp_customize->add_setting('testimonial_homepage_title', array(
		'default' => esc_html__('Whats Our Clients Say','the-consult'),
		'sanitize_callback' => 'sanitize_text_field',
		));

	$wp_customize->add_control('testimonial_homepage_title',array(
		'type' => 'text',
		'label' => esc_html__('Testimonial Section Title','the-consult'),
		'section' => 'the_consult_testimonial_setups',
		'setting' => 'testimonial_homepage_title'
	));
    
	//Testimonial  image
    $wp_customize->add_setting('the_consult_testimonial_bkgimage', array(
		'default' => '',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'the_consult_testimonial_bkgimage', array(
		'label' => esc_html__('Image for Testimonial Section', 'the-consult'),
		'section' => 'the_consult_testimonial_setups',
		 'priority'  => '100',
		'setting' => 'the_consult_testimonial_bkgimage'
	)));
	             
    // Starting Latest Post Section
    $wp_customize->add_section('the_consult_portfolio_post_setups',array(
		'priority' => '10',
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__('Portfolio Section','the-consult'),
		'description' => esc_html__('Manage This Section for the site','the-consult'),
		'panel' => 'the_consult_homepage_setups'
	)); 
    
    // Enable/Disable This Section
    $wp_customize->add_setting('the_consult_portfolio_post_option',array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_portfolio_post_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section','the-consult'),
        'section'       =>  'the_consult_portfolio_post_setups',
        'setting'       =>  'the_consult_portfolio_post_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
	
    //category for the Latest Post  section
 	$wp_customize->add_setting('the_consult_portfolio_post_section_category',array(
        'default'           =>  '0',
        'sanitize_callback' =>  'the_consult_sanitize_category_select',
        )
    );
    $wp_customize->add_control('the_consult_portfolio_post_section_category',array(
        'priority'      =>  20,
        'label'         =>  esc_html__('Select category','the-consult'),
        'section'       =>  'the_consult_portfolio_post_setups',
        'setting'       =>  'the_consult_portfolio_post_section_category',
        'type'          =>  'select',  
        'choices'       =>  $the_consult_category_lists
        )                                     
    );
    
    // Portfolio Post title
    $wp_customize->add_setting('portfolio_post_homepage_title', array(
    	'default' => esc_html__('Portfolio Post','the-consult'),
    	'sanitize_callback' => 'sanitize_text_field',
	));

	$wp_customize->add_control('portfolio_post_homepage_title',array(
    	'type' => 'text',
    	'label' => esc_html__('Portfolio Section Title','the-consult'),
    	'section' => 'the_consult_portfolio_post_setups',
    	'setting' => 'portfolio_post_homepage_title'
	));
    
    //Latest section Subtitle
    $wp_customize->add_setting('the_consult_portfolio_desc', array(
    'default' => '',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_control('the_consult_portfolio_desc',array(
        'type' => 'text',
        'label' => esc_html__('Portfolio Post Section Subtitle','the-consult'),
        'section' => 'the_consult_portfolio_post_setups',
        'setting' => 'the_consult_portfolio_desc'
    ));
    
    //starting footer Setting
    $wp_customize -> add_panel(
        'the_consult_footer_setting_panel',array(
            'priority' => 35,
            'capability' => 'edit_theme_options',
            'theme_supports' => '',
            'title' => esc_html__('Footer Setup', 'the-consult')
        )
    );
    $wp_customize->add_section(
        'the_consult_social_link',array(
            'title' =>esc_html__('Footer Social Link','the-consult'),
            'panel' =>'the_consult_footer_setting_panel',
        )
    );
    
    //enble/disable footer social section
    $wp_customize->add_setting('the_consult_footer_option',array(
        'default'           =>  'no',
        'sanitize_callback' =>  'the_consult_sanitize_radio_yes_no',
        )
    );
    $wp_customize->add_control('the_consult_footer_option',array(
        'description'   =>  esc_html__('Enable/Disable This Section?','the-consult'),
        'section'       =>  'the_consult_social_link',
        'setting'       =>  'the_consult_footer_option',
        'priority'      =>  5,
        'type'          =>  'radio',
        'choices'        =>  array(
            'yes'   =>  esc_html__('Yes','the-consult'),
            'no'    =>  esc_html__('No','the-consult')
            )
        )                   
    );
    
    $wp_customize->add_setting(
        'the_consult_facebook_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    $wp_customize->add_control(
        'the_consult_facebook_text', array(
                'label' => esc_html__('Facebook Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
    
    $wp_customize->add_setting(
        'the_consult_twitter_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    $wp_customize->add_control(
        'the_consult_twitter_text',array(
                'label' => esc_html__('Twitter Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
    
    $wp_customize->add_setting(
        'the_consult_googleplus_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    $wp_customize->add_control(
        'the_consult_googleplus_text',array(
                'label' => esc_html__('GooglePlus Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
    $wp_customize->add_setting(
        'the_consult_youtube_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    
    $wp_customize->add_control(
        'the_consult_youtube_text',array(
                'label' => esc_html__('Youtube Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
    $wp_customize->add_setting(
        'the_consult_pinterest_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    
   $wp_customize->add_control(
        'the_consult_pinterest_text',array(
                'label' => esc_html__('Pinterest Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
    $wp_customize->add_setting(
        'the_consult_linkedin_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    
     $wp_customize->add_control(
        'the_consult_linkedin_text',array(
                'label' => esc_html__('Linkedin Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
     $wp_customize->add_setting(
        'the_consult_instagram_text',array(
                'default'=>'',
                'sanitize_callback' => 'esc_url_raw',
            )
    );
    
    $wp_customize->add_control(
        'the_consult_instagram_text',array(
                'label' => esc_html__('Instagram Link','the-consult'),
                'section' => 'the_consult_social_link',
                'type' => 'text',
            )
    );
	
    //starting footer copy right section
    $wp_customize->add_section(
        'the_consult_footer_cpy',array(
            'title' =>esc_html__('Footer Copyright Section','the-consult'),
            'panel' =>'the_consult_footer_setting_panel',
        )
    );
    
    $wp_customize->add_setting(
    'the_consult_footer_setting_cpy_text',array(
        'default'           =>  esc_html__('Themeruler','the-consult'),
        'sanitize_callback' =>  'sanitize_text_field',
        'transport'			=>	'postMessage',
        )
    );
	$wp_customize->add_control(
        'the_consult_footer_setting_cpy_text',array(
        'priority'      =>  8,
        'label'         =>  esc_html__('Footer Copyright text','the-consult'),
        'section'       =>  'the_consult_footer_cpy',
        'setting'       =>  'the_consult_footer_setting_cpy_text',
        'type'          =>  'text',  
        )
    );  	          
 }
add_action( 'customize_register', 'the_consult_custom_customize_register' );